# Future Development

**Piplexed** is a project that I built for my workflow, but it may not work for everyone.

It is only intended to work for packages that are installed from [PyPI](https://pypi.org), so will not work for local packages or git/url etc.


There are several areas I am thinking about improving:

- Adding concurrency to speed up response time.
- Provide an additional view of output as a table (takes up less screen space).
- Highlighting when a new version is a major version increase.
- Somehow getting changelog information (if available) and providing an option to display it.
